"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getConfig = void 0;
const cypress_1 = require("cypress");
const task_1 = __importDefault(require("@cypress/code-coverage/task"));
const fs_1 = require("fs");
const setRemovingVideosForPassedTestsTask = (on) => {
    // Delete the recorded video for specs that had no retry attempts
    // https://github.com/cypress-io/cypress/issues/16377
    on('after:spec', async (_spec, results) => {
        if (results && results.video) {
            const failedTests = results.tests?.some(test => test.attempts.some(attempt => attempt?.state === 'failed'));
            if (!failedTests && results.video) {
                await fs_1.promises.unlink(results.video);
            }
        }
    });
};
/**
 * Creates common cypress configuration
 *
 * @param localBaseUrl
 * @param webpackConfig
 */
function getConfig(localBaseUrl, webpackConfig) {
    const { MANAGER_IP, MANAGER_PROTOCOL = 'http' } = process.env;
    const baseUrl = MANAGER_IP ? `${MANAGER_PROTOCOL}://${MANAGER_IP}` : localBaseUrl;
    const setupNodeEvents = (on, config) => {
        (0, task_1.default)(on, config);
        setRemovingVideosForPassedTestsTask(on);
    };
    return (0, cypress_1.defineConfig)({
        fixturesFolder: 'test/cypress/fixtures',
        screenshotsFolder: 'test/cypress/screenshots',
        videosFolder: 'test/cypress/videos',
        defaultCommandTimeout: 15000,
        video: true,
        reporter: 'junit',
        reporterOptions: {
            mochaFile: 'test/cypress/results/test-results-[hash].xml',
            testCaseSwitchClassnameAndName: true
        },
        videoUploadOnPasses: false,
        watchForFileChanges: false,
        nodeVersion: 'system',
        e2e: {
            setupNodeEvents: (on, config) => {
                setupNodeEvents(on, config);
                console.info(`Testing on: ${baseUrl}`);
            },
            specPattern: 'test/cypress/integration/**/*_spec.ts',
            supportFile: 'test/cypress/support/index.ts',
            baseUrl
        },
        component: {
            devServer: {
                framework: 'react',
                bundler: 'webpack',
                webpackConfig
            },
            setupNodeEvents,
            viewportWidth: 850,
            viewportHeight: 800,
            specPattern: 'test/cypress/components/**/*_spec.tsx',
            supportFile: 'test/cypress/support/index.ts',
            indexHtmlFile: 'test/cypress/support/component-index.html'
        }
    });
}
exports.getConfig = getConfig;
//# sourceMappingURL=index.js.map